@@ -53,15 +53,18 @@ class AliasManager:
             pickle.dump(self._aliases, f)
 
     def load_aliases(self):
+        logging.info("Reading aliases")
         try:
             with open(ALIAS_FILE, "rb") as f:
-                logging.info("Reading aliases")
                 self._aliases = pickle.load(f)
         except:
             logging.info("Failed to read aliases from file")
             pass
 
     def print_aliases(self):
+        if len(self._aliases) == 0:
+            print("No current aliases")
+            return
 
         # Find the longest alias name
         max_alias = 0
