@@ -10,6 +10,7 @@ from signal import SIGINT, signal
 import soco
 
 from .action_processor import list_actions, process_action
+from .cmd_parser import CLIParser
 from .interactive import interactive_loop
 from .speakers import Speakers
 from .utils import (
@@ -28,6 +29,8 @@ from .utils import (
     sig_handler,
     version,
 )
+from .wait_actions import process_wait
+
 
 # Globals
 pp = pprint.PrettyPrinter(width=100)
@@ -156,46 +159,9 @@ def main():
         )
         exit(0)
 
-    # Break up the command line into command sequences, observing the separator.
-    command_line_separator = ":"
-    sequence = []  # A single command sequence
-    sequences = []  # A list of command sequences
-    for arg in args.parameters:
-        if len(arg) > 1 and command_line_separator in arg:
-            # Catch special cases of colon use: HH:MM(:SS) time formats,
-            # and URLs
-            if not (
-                sequence
-                and sequence[-1]
-                in [
-                    "wait",
-                    "wait_for",
-                    "wait_until",
-                    "seek",
-                    "seek_to",
-                    "seek_forward",
-                    "sf",
-                    "seek_back",
-                    "sb",
-                    "sleep",
-                    "sleep_timer",
-                    "sleep_at",
-                    "wait_stopped_for",
-                    "loop_for",
-                    "loop_until",
-                ]
-                or ":/" in arg
-            ):
-                error_and_exit(
-                    "Spaces are required each side of the ':' command separator"
-                )
-        if arg != command_line_separator:
-            sequence.append(arg)
-        else:
-            sequences.append(sequence)
-            sequence = []
-    if sequence:
-        sequences.append(sequence)
+    cli_parser = CLIParser()
+    cli_parser.parse(args.parameters)
+    sequences = cli_parser.get_sequences()
 
     # Loop through processing command sequences
     logging.info("Found {} action sequence(s): {}".format(len(sequences), sequences))
@@ -318,39 +284,9 @@ def main():
                 sequence_pointer = loop_pointer
                 continue
 
-            # Special case: the 'wait' action
-            if speaker_name in ["wait", "wait_for"]:
-                duration = 0
-                if len(sequence) != 2:
-                    error_and_exit(
-                        "Action 'wait' requires 1 parameter (check spaces around the ':' separator)"
-                    )
-                action = sequence[1].lower()
-                try:
-                    duration = convert_to_seconds(action)
-                except ValueError:
-                    error_and_exit(
-                        "Action 'wait' requires positive number of hours, seconds or minutes + 'h/m/s', or HH:MM(:SS)"
-                    )
-                logging.info("Waiting for {}s".format(duration))
-                time.sleep(duration)
-                continue
-
-            # Special case: the 'wait_until' action
-            elif speaker_name in ["wait_until"]:
-                if len(sequence) != 2:
-                    error_and_exit(
-                        "'wait_until' requires 1 parameter (check spaces around the ':' separator)"
-                    )
-                try:
-                    action = sequence[1].lower()
-                    duration = seconds_until(action)
-                    logging.info("Waiting for {}s".format(duration))
-                    time.sleep(duration)
-                except ValueError:
-                    error_and_exit(
-                        "'wait_until' requires parameter: time in 24hr HH:MM(:SS) format"
-                    )
+            # Special case: the 'wait' actions
+            if speaker_name in ["wait", "wait_for", "wait_until"]:
+                process_wait(sequence)
                 continue
 
             # Use the speaker name from the environment?
@@ -410,7 +346,5 @@ def main():
     exit(0)
 
 
-2
-
 if __name__ == "__main__":
     main()
