@@ -318,6 +318,23 @@ class RewindableList(Sequence):
         else:
             raise IndexError
 
+    def __str__(self):
+        return str(self._items)
+
+    def index(self):
+        return self._index
+
+    def insert(self, index, element):
+        self._items.insert(index, element)
+        if index <= self._index:
+            self._index += 1
+
+    def pop_next(self):
+        item = self._items.pop(0)
+        if self._index != 0:
+            self._index -= 1
+        return item
+
 
 # Set up logging
 def configure_logging(log_level):
@@ -649,11 +666,20 @@ def read_search():
 
 
 # Interactive shell history file
-HIST_FILE = os.path.join(os.path.expanduser("~"), ".soco-cli", "shell-history.txt")
+SOCO_CLI_DIR = os.path.join(os.path.expanduser("~"), ".soco-cli")
+HIST_FILE = os.path.join(SOCO_CLI_DIR, "shell-history.txt")
 HIST_LEN = 50
 
 
 def save_readline_history():
+    if not os.path.exists(SOCO_CLI_DIR):
+        logging.info("Creating directory '{}'".format(SOCO_CLI_DIR))
+        try:
+            os.mkdir(SOCO_CLI_DIR)
+        except:
+            error_and_exit("Failed to create directory '{}'".format(SOCO_CLI_DIR))
+            return
+
     logging.info("Saving shell history file: {}".format(HIST_FILE))
     try:
         readline.write_history_file(HIST_FILE)
